/*
 * \file lcdled.c
 *
 * \date Feb 8, 2017
 * \author Ting
 */

#include "atrasos.h"
#include "lcdled.h"

/**
* \brief Inicializa como GPIO A12, B18, B19, C0-10 e D1 
*/
void initLcdledGPIO(void) {
}

/*!
 * \fn pulso (char p)
 * \brief Gera um pulso "Enable" de t*1us.
 * \param[in] p para LCD (p=0) e para Leds (p=1).
 */
void pulso(tipo_enable p, uint8_t t) {
	GPIOC_PSOR = GPIO_PIN (9 + p);     ///< Seta 1 no PORTC[9+p]
	GPIOC_PCOR = GPIO_PIN (9 + p);       ///< Limpa em 0 o PORTC[9+p]
	delay10us(t);                        ///< mant&eacute;m aprox. t*10us
}

/*!
 * \fn RS (uint8_t l)
 * \brief Envia ao LCD o sinal RS pelo pino PORTC[8].
 * \param[in] l valor do RS (0, byte de instru&ccedil;&atilde;o e 1, byte de dados).
 */
void RS(uint8_t l) {
	if(l) {                      ///< (l != 0)
		GPIOC_PSOR = GPIO_PIN(8);    ///< Seta o LCD no modo de dados
	} else {   
		GPIOC_PCOR = GPIO_PIN(8);     ///< Seta o LCD no modo de instru&ccedil;&atilde;o
	}
}

/*!
 * \fn enviaLCD (char c)
 * \brief Envia ao LCD um byte pelos pinos PORTC[7:0]
 * \param[in] c caracter em ASCII.
 * \param[in] t tempo de processamento necess&aacute;rio.
 */
void enviaLCD(char c, uint8_t t) {
	GPIOC_PCOR = 0x000000FF;      ///< limpa em 0 PORTC[7:0]
	GPIOC_PSOR = (unsigned int)c; ///< Seta os bits que devem ser setados
	pulso(0, t);                      ///< dispara o pulso "Enable" do LCD
}

/*!
 * \fn enviaLed (char c)
 * \brief Envia ao LED um byte pelos pinos PORTC[7:0]
 * \param[in] c caracter em ASCII.
 * \param[in] t tempo de processamento necess&aacute;rio.
 */
void enviaLed(char c) {
	GPIOC_PCOR = 0x000000FF;      ///< limpa em 0 PORTC[7:0]
	GPIOC_PSOR = (unsigned int)c; ///< Seta os bits que devem ser setados
	pulso(1, 1);                      ///< dispara o pulso "Enable" do Latch 74573
}

/*!
 * \fn inicLCD (void) 
 * \brief Inicializa o LCD com a sequ&ecirc;ncia de instru&ccedil;&otilde;es recomendada pelo fabricante
 */
void initLCD(void) {


/*!
 * \fn mandaString (char *s)
 * \brief Envia uma string de caracteres.
 * \param[in] s endere&ccedil;o inicial da string.
 */
void mandaString(char * s) {
}

/*!
 * \fn limpaLCD (void) 
 * \brief Envia a instruo "Clear Display" (0x01).
 */
void limpaLCD(void) {
}

/*!
 * \fn criaBitmapI (uint8_t end)
 * \brief Cria um bitmap "&iacute;"
 * \param[in] end endere&ccedil;o onde o bitmap &eacute; gravado
 * \param[in] bitmap matriz do bitmap
 */
void criaBitmap(uint8_t end, uint8_t *bitmap){
}
