/*!
 * @file ledRGB.c
 * @brief Gerencia o led RGB
 * @date Feb 7, 2017
 * @author Ting
 */
#include "ledRGB.h"

/*!
 * @brief Inicializa os registradores relacionados com o led R
 */
void initLedR() {
	SIM_SCGC5 = SIM_SCGC5 | (1<<10);    /*!  Habilita clock GPIO do PORTB */
	PORTB_PCR18 = PORTB_PCR18 & 0xFFFFF8FF; /*! Zera bits 10, 9 e 8 (MUX) de PTB18 */
	PORTB_PCR18 = PORTB_PCR18 | 0x00000100; /*! Seta bit 8 do MUX de PTB18, assim os 3 bits de MUX ser&atilde;o 001 = fun&ccedil;&atilde;o GPIO */
	GPIOB_PDDR  = GPIOB_PDDR  | (1<<18);    /*! Seta dire&ccedil;&atilde;o do pino 18 de PORTB como sa&iacute;da */
}

/*!
 * @brief Liga led R
 * @note
 * Atribuir 0 nos bits do registrador PCOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void ligaLedR() {
	GPIOB_PCOR = (1<<18); /*! Limpa bit 18, LED vermelho em PTB18 (acende) */	
}

/*!
 * @brief Apaga led R
 * @note
 * Atribuir 0 nos bits do registrador PSOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void apagaLedR() {
	GPIOB_PSOR = (1<<18);     /*! Seta bit 18, LED vermelho em PTB18 (apaga) */
}

/*!
 * @brief Alterna led R

 * @note

 * Atribuir 0 nos bits do registrador PTOR n&atilde;o afeta o estado dos pinos correspondentes.

 */
void alternaLedR() {
	GPIOB_PTOR = (1<<18);     /*! Seta bit 18, LED vermelho em PTB18 (alterna) */
}

/**
 * @brief Inicializa o led RGB
 */
void initLedRGB() {
    SIM_SCGC5 |= (SIM_SCGC5_PORTB_MASK |
			  SIM_SCGC5_PORTD_MASK) ;    
	
    /*! Configura pino B18 como GPIO (MUX = 001) */
    PORTB_PCR18 |= PORT_PCR_MUX(0x1);

    /*! Configura pino B19 como GPIO (MUX = 001) */
    PORTB_PCR19 |= PORT_PCR_MUX(0x1);

    /*! Configura a direcao dos pinos 18 e 19 da PORTB como sa&iacute;da */
    GPIOB_PDDR |= GPIO_PDDR_PDD(GPIO_PIN(18)) |
    			  GPIO_PDDR_PDD(GPIO_PIN(19));

    /*! Inicializa os pinos 18 e 19 */
    GPIOB_PSOR = GPIO_PDDR_PDD(GPIO_PIN(18)) |
			     GPIO_PDDR_PDD(GPIO_PIN(19));

    /*! Configura pino D1 como GPIO (MUX = 001) */
    PORTD_PCR1 |= PORT_PCR_MUX(0x1);

    /*! Configura a diire&ccedil;&atilde;o dos pino 1 da PORTD como sa&iacute;da */
    GPIOD_PDDR |= GPIO_PDDR_PDD(GPIO_PIN(1));
    
    /*! Inicializa o pino 1 */
    GPIOD_PSOR |= GPIO_PDDR_PDD(GPIO_PIN(1));
}

/*!
 * @brief Liga led G
 * @note
 * Atribuir 0 nos bits do registrador PCOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void ligaLedG() {
}

/*!
 * @brief Apaga led G

 * @note
 * Atribuir 0 nos bits do registrador PSOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void apagaLedG() {
}

/*!
 * @brief Alterna led G
 * @note
 * Atribuir 0 nos bits do registrador PTOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void alternaLedG() {
	GPIOB_PTOR = (1<<19);     /*! Seta bit 18, LED verde em PTB19 (alterna) */
}

/*!
 * @brief Liga led B
 * @note
 * Atribuir 0 nos bits do registrador PCOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void ligaLedB() {
}

/*!
 * @brief Apaga led B
 * @note
 * Atribuir 0 nos bits do registrador PSOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void apagaLedB() {
}

/*!
 * @brief Alterna led B
 * @note
 * Atribuir 0 nos bits do registrador PTOR n&atilde;o afeta o estado dos pinos correspondentes.
 */
void alternaLedB() {
}

/**
* @brief Seta o estado do led
* @param[in] tipo vermelho, verde e azul
* @param[in] aceso (1) ou apagado (0) 
*/
void led (enum _tipo_led tipo, enum _estado_led estado) {
	switch(tipo)
	{
		case VERMELHO:
            if (estado == ACESO)
            	GPIOB_PCOR = GPIO_PIN(18); /*! Clear bit 18 de PTB, LED vermelho acende */
            else
            	GPIOB_PSOR = GPIO_PIN(18); /*! Set bit 18 de PTB, LED vermelho apaga */
            break;
		case VERDE:
            if (estado == ACESO)
            	GPIOB_PCOR = GPIO_PIN(19); /*! Clear bit 19 de PTB, LED verde acende */
            else
            	GPIOB_PSOR = GPIO_PIN(19); /*! Set bit 19 de PTB, LED verde apaga */
            break;
		case AZUL:
            if (estado == ACESO)
            	GPIOD_PCOR = GPIO_PIN(1); /*! Clear bit 1 de PTD, LED azul acende */
            else
            	GPIOD_PSOR = GPIO_PIN(1); /*! Set bit 1 de PTD, LED azul apaga */
	}
}

/*!
 * @brief Apaga led RGB
 */
void apagaLedRGB() {
	GPIOB_PSOR = GPIO_PIN(18)|GPIO_PIN(19); /*! LED vermelho e verde apagam */
	GPIOD_PSOR = GPIO_PIN(1);                /*! LED azul apaga*/
}
