/*
 * \file nvic.c
 *
 * \date Feb 14, 2017
 * \author: Ting
 */

#include "nvic.h"

/*!
 * \fn enableNVICPTA (void)
 * \brief Habilita interrup&ccedil;&otilde;es da PORTA no NVIC.
 * \param[in] priority level
 */
void enableNVICPTA(uint8_t priority) {
	/* 
	 * "Non-core interrupt source count" (IRQ = Vector Number (46) - 16, 
	 * Table 3-7 de KL-25 Sub-Family Reference Manual) &eacute; habilitado
	 * ao escrever 1 no bit correpondente do registrador NVIC_ISER 
	 * (B3.4.3 de ARMv6-M Architecture Reference Manual) e a solicita&ccedil;&atilde;o de 
	 * interrup&ccedil;&atilde;o &eacute; limpa ao escrever 1 no bit correspondente do 
	 * registrador NVIC_ICPR (B3.4.6 de ARMv6-M Architecture Reference Manual) 
	 */
	/*! PORTA: Vetor 46, IRQ30, prioridade em NVICIPR7[23:16]
	 * Se&ccedil;&atilde;o 3.3.2.3 em 
	 * <a href="ftp://ftp.dca.fee.unicamp.br/pub/docs/ea871/ARM/KL25P80M48SF0RM.pdf" target=_manual>ftp://ftp.dca.fee.unicamp.br/pub/docs/ea871/ARM/KL25P80M48SF0RM.pdf</a>
	 */
    NVIC_ISER |= 1 << (xxxx);            ///< Habilita interrup&ccedil;&atilde;o PORTA
    NVIC_ICPR |= 1 << (xxxx);
    NVIC_IPR7 |= NVIC_IP_PRI_30(xxxx);    ///< N&iacute;vel de prioridade = 3
}

/**
 * \fn enableNVICPIT (void)
 * 
 * \brief Habilita interrup&ccedil;&atilde;o do m&oacute;dulo PIT 
 * (vetor de interrup&ccedil;&atilde;o = 38) no NVIC.
 * \param[in] priority level
 */
void enableNVICPIT(uint8_t priority) {
    NVIC_ISER |= 1 << (xxxx);         ///< NVIC_ISER[22]=1 (habilita IRQ22)
    NVIC_ICPR |= 1 << (xxxx);         ///< NVIC_ICPR[22]=1 (limpa as pendncias)
    NVIC_IPR5 |= NVIC_IP_PRI_22(xxxx); ///< NVIC IPR register number na Table 3-7 
    						           ///< de KL-25 Sub-Family Reference Manual
    		                           ///< seta prioridade 1			
}
